@@ -12,20 +12,20 @@ def process_input_output_path(book: Book):
     :param book: 书籍路径
     :return: book, output
     """
-    if book.book_path != ".":
-        if not os.path.isdir(book.book_path):
-            dir_not_found_error(book.book_path, "书籍路径不存在")
 
-    book.book_path = os.path.abspath(book.book_path)
+    book.book_path = get_abspath(book.book_path)
     logging.info(f"书籍目录：{book.book_path}")
 
-    book.book_output = os.path.join(book.book_path, book.book_output)
+    if not os.path.isdir(book.book_path):
+        dir_not_found_error(book.book_path)
+
+    book.book_output = get_abspath(book.book_path, book.book_output)
     logging.info(f"输出目录：{book.book_output}")
 
-    book.assets_path = os.path.join(os.path.split(os.path.dirname(__file__))[0], *book.assets_path)
+    book.assets_path = get_abspath(os.path.split(os.path.dirname(__file__))[0], *book.assets_path)
     logging.debug(f"资源路径：{book.assets_path}")
 
-    book.assets_path_out = os.path.join(book.book_output, book.assets_path_out)
+    book.assets_path_out = get_abspath(book.book_output, book.assets_path_out)
     logging.debug(f"资源输出路径：{book.assets_path_out}")
 
 
@@ -44,6 +44,11 @@ def set_extension(filename, ext):
     return get_filename_not_ext(filename) + ext
 
 
-def get_pure_path(path):
+def get_pure_path(path, *paths):
     """获取路径，分隔符为 / """
-    return Path(path).as_posix()
+    return Path(os.path.join(path, *paths)).as_posix()
+
+
+def get_abspath(path, *paths):
+    """获取绝对路径"""
+    return os.path.abspath(get_pure_path(path, *paths))
